@@ -1,5 +1,5 @@
 /*
- * $Id: ft_netorg.c,v 1.38 2004/05/08 02:37:27 jasta Exp $
+ * $Id: ft_netorg.c,v 1.39 2004/08/02 23:59:27 hexwab Exp $
  *
  * Copyright (C) 2001-2003 giFT project (gift.sourceforge.net)
  *
@@ -481,6 +481,61 @@ static BOOL length_dummy (FTNode *node, void *udata)
 }
 #endif /* VERIFY_NETORG_LENGTH */
 
+static void randomize_conn_iptr (ft_state_t state)
+{
+	struct conn_list *clist = NULL;
+	int new_pos;
+
+	if (!(clist = get_conn_list (state)))
+		return;
+
+	if (clist->list == NULL || clist->count == 0)
+		return;
+
+	/* set clist->iptr to random point in list */
+	new_pos = rand() % clist->count;
+	clist->iptr = list_nth (clist->list->list, new_pos);
+
+	/* just in case anything went wrong */
+	if (clist->iptr == NULL)
+		clist->iptr = (clist->list ? clist->list->list : NULL);
+}
+
+int ft_netorg_random (ft_class_t klass, ft_state_t state, int iter,
+                      FTNetorgForeach func, void *udata)
+{
+	int looped = 0;
+
+	if (!func)
+		return 0;
+
+	if (state)
+	{
+		randomize_conn_iptr (state);
+		looped = foreach_list (klass, state, iter, func, udata);
+	}
+	else
+	{
+		/* state = 0x00 indicates that all states should be processed,
+		 * therefore requiring multiple calls to foreach_list that are
+		 * capable of persisting iteration data */
+		randomize_conn_iptr (FT_NODE_CONNECTED);
+		randomize_conn_iptr (FT_NODE_CONNECTING);
+		randomize_conn_iptr (FT_NODE_DISCONNECTED);
+
+		iter_state (klass, FT_NODE_CONNECTED, iter, &looped, func, udata);
+		iter_state (klass, FT_NODE_CONNECTING, iter, &looped, func, udata);
+		iter_state (klass, FT_NODE_DISCONNECTED, iter, &looped, func, udata);
+	}
+
+	if (iter)
+		assert (looped <= iter);
+
+	return looped;
+}
+
+/*****************************************************************************/
+
 int ft_netorg_length (ft_class_t klass, ft_state_t state)
 {
 	int klass_idx, state_idx;
