@@ -1,5 +1,5 @@
 /*
- * $Id: ft_packet.c,v 1.47 2004/04/24 07:03:11 jasta Exp $
+ * $Id: ft_packet.c,v 1.49 2004/10/31 22:19:23 hexwab Exp $
  *
  * Copyright (C) 2001-2003 giFT project (gift.sourceforge.net)
  *
@@ -400,11 +400,17 @@ BOOL ft_packet_put_raw (FTPacket *packet, unsigned char *str, size_t len)
 
 static BOOL check_overrun (FTPacket *packet, size_t size)
 {
+	size_t req;
+
 	assert (packet != NULL);
 
-	if (packet->offset + size > packet->len)
+	req = packet->offset + size;
+
+	if (req > packet->len)
 	{
-		packet->overrun += size;
+		packet->offset = packet->len;
+		packet->overrun += (req - packet->len);
+
 		return TRUE;
 	}
 
@@ -635,6 +641,32 @@ int ft_packet_send (TCPC *c, FTPacket *packet)
 	return ret;
 }
 
+int ft_packet_send_streamed (TCPC *c, FTPacket *packet)
+{
+	FTSession *session;
+
+	if (!c || !FT_NODE(c) || !(session = FT_SESSION(c)))
+		return ft_packet_send (c, packet);
+
+	/* yes, this drops the packet on the floor */
+	if (session->stage < 4)
+	{
+		ft_packet_free (packet);
+		return 0;
+	}
+
+	if (!session->autoflushed)
+	{
+		session->autoflushed = ft_stream_get (c, FT_STREAM_SEND | FT_STREAM_AUTOFLUSH, NULL);
+		session->af_pkts = 0;
+
+		FT->DBGFN (FT, "creating autoflushed stream for %s: %p", ft_node_fmt (FT_NODE(c)), session->autoflushed);
+		assert (session->autoflushed);
+	}
+	
+	return ft_stream_send (session->autoflushed, packet);
+}
+
 static int locate_to (FTNode *node, in_addr_t *ip)
 {
 	/* we request info on a specific ip address and upon receiving this
