@@ -1,5 +1,5 @@
 /*
- * $Id: ft_session.c,v 1.89 2003/12/23 21:29:39 jasta Exp $
+ * $Id: ft_session.c,v 1.93 2004/11/13 19:37:59 hexwab Exp $
  *
  * Copyright (C) 2001-2003 giFT project (gift.sourceforge.net)
  *
@@ -273,6 +273,7 @@ static void session_reset_data (FTSession *s)
 
 	/* flush everything else */
 	memset (&s->stats, 0, sizeof (s->stats));
+	s->stats.size = 0;
 	s->stage = 0;
 	s->start = 0;
 	s->verified = FALSE;
@@ -530,6 +531,46 @@ int ft_session_queue (TCPC *c, FTPacket *packet)
 
 /*****************************************************************************/
 
+static BOOL tidy_stream (FTNode *node, int *total)
+{
+	FTSession *session = node->session;
+
+	assert (session);
+	
+	if (!session->autoflushed)
+		return FALSE;
+	
+	(*total)++;
+
+	if (session->af_pkts == session->autoflushed->pkts)
+	{
+		ft_stream_finish (session->autoflushed);
+		session->autoflushed = NULL;
+		session->af_pkts = 0;
+
+		return TRUE;
+	}
+
+	session->af_pkts = session->autoflushed->pkts;
+
+	return FALSE;
+}
+
+void ft_session_tidy_streams (void)
+{
+	int tidied, total;
+
+	total = 0;
+
+	tidied = ft_netorg_foreach (FT_NODE_CLASSANY, FT_NODE_CONNECTED, 0,
+			    FT_NETORG_FOREACH(tidy_stream), &total);
+
+	if (total)
+		FT->DBGFN (FT, "cleaned up %d of %d autoflushed streams", tidied, total);
+}
+
+/*****************************************************************************/
+
 static void connect_complete (TCPC *c, int fd, input_id id, int incoming)
 {
 	char *err = NULL;
