@@ -1,5 +1,5 @@
 /*
- * $Id: ft_query.c,v 1.15 2003/11/21 16:05:18 jasta Exp $
+ * $Id: ft_query.c,v 1.16 2004/10/31 22:19:23 hexwab Exp $
  *
  * Copyright (C) 2001-2003 giFT project (gift.sourceforge.net)
  *
@@ -504,7 +504,7 @@ static int forward_search_peer (FTNode *node, sparams_t *params)
 	ft_packet_put_str (pkt, params->realm);
 
 	/* deliver the search query */
-	if (ft_packet_send (FT_CONN(node), pkt) < 0)
+	if (ft_packet_send_streamed (FT_CONN(node), pkt) < 0)
 	{
 		ft_search_fwd_finish (sfwd);
 		return FALSE;
@@ -915,7 +915,7 @@ static void handle_forward_result (TCPC *c, FTPacket *pkt, ft_guid_t *guid,
 	if ((data = ft_packet_get_raw (pkt, &len)))
 		ft_packet_put_raw (fwd, data, len);
 
-	ft_packet_send (FT_CONN(src), fwd);
+	ft_packet_send_streamed (FT_CONN(src), fwd);
 }
 
 static void handle_search_sentinel (TCPC *c, FTPacket *pkt, ft_guid_t *guid,
